@@ -1,6 +1,6 @@
 #! /bin/sh
 
-# Copyright (C) 2001-2011 Peter Selinger.
+# Copyright (C) 2001-2013 Peter Selinger.
 # This file is part of Potrace. It is free software and it is covered
 # by the GNU General Public License. See the file COPYING for details.
 
@@ -34,19 +34,25 @@ action () {
 # keep track of line numbers
 alias action="LINE=\$LINENO; action"
 
+dofiles() {
+  action $MKBITMAP -o "$TMP1" "$srcdir/$1"
+  shift
+
+  for i in "$@"; do
+      action $MKBITMAP -o "$TMP2" "$srcdir/$i"
+      action diff "$TMP1" "$TMP2" > /dev/null
+      action rm -f "$TMP2"
+  done
+}
+
 # available input files
-INFILES="data1.pbm data1.pgm data1.ppm data1.bmp1 data1.bmp4 data1.bmp8 data1.bmp24 data1.bmp24td data1.bmp24v5 data1.bmp4r data1.bmp8r"
+INFILES="data1.pbm data1.pgm data1.ppm data1.bmp1 data1.bmp4 data1.bmp8 data1.bmp24 data1.bmp24td data1.bmp24v5 data1.bmp32 data1.bmp32bf data1.bmp4r data1.bmp8r"
 
-# extract first file
-set dummy $INFILES; F="$2"
+dofiles $INFILES
 
-action $MKBITMAP -o "$TMP1" "$srcdir/$F"
+INFILES="data2.ppm data2.bmp32bf"
 
-for i in $INFILES; do
-    action $MKBITMAP -o "$TMP2" "$srcdir/$i"
-    action diff "$TMP1" "$TMP2" > /dev/null
-    action rm -f "$TMP2"
-done
+dofiles $INFILES
 
 action rm -f "$TMP1"
 
