@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2011 Peter Selinger.
+/* Copyright (C) 2001-2013 Peter Selinger.
    This file is part of Potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
@@ -25,11 +25,6 @@
 
 typedef int color_t;
 
-#define black  0x000000
-#define red    0xff0000
-#define green  0x008000
-#define blue   0x0000ff
-
 /* ---------------------------------------------------------------------- */
 /* auxiliary: growing arrays */
 
@@ -192,7 +187,6 @@ static char *pdf_colorstring(const color_t col) {
 }
 
 static color_t pdf_color = -1;
-static double pdf_width = -1;
 
 static void pdf_setcolor(const color_t col) {
   if (col == pdf_color) {
@@ -289,7 +283,7 @@ int init_pdf(FILE *fout)
 	intarray_set(&xref, nxref++, outcount);
 	shipclear("2 0 obj\n"
 		"<</Creator"
-		"("POTRACE" "VERSION", written by Peter Selinger 2001-2011)>>\n"
+		"("POTRACE" "VERSION", written by Peter Selinger 2001-2013)>>\n"
 		"endobj\n");
 
 	/* delay obj #3 (pages) until end */
@@ -343,7 +337,6 @@ static void pdf_pageinit(imginfo_t *imginfo, int largebbox)
 	double pageh = imginfo->trans.bb[1]+imginfo->tmar+imginfo->bmar;
 
 	pdf_color = -1;
-	pdf_width = -1;
 
 	intarray_set(&xref, nxref++, outcount);
 	shipclear("%d 0 obj\n", nxref);
