@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2011 Peter Selinger.
+/* Copyright (C) 2001-2013 Peter Selinger.
    This file is part of Potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
@@ -18,6 +18,7 @@
 #include "backend_svg.h"
 #include "backend_xfig.h"
 #include "backend_dxf.h"
+#include "backend_geojson.h"
 #include "potracelib.h"
 #include "bitmap_io.h"
 #include "bitmap.h"
@@ -105,6 +106,7 @@ static backend_t backend[] = {
   { "pdfpage",    ".pdf", 1, 0, 1,   init_pdf, page_pdfpage, term_pdf, 1 },
   { "svg",        ".svg", 0, 0, 0,   NULL,     page_svg,     NULL,     1 },
   { "dxf",        ".dxf", 0, 1, 0,   NULL,     page_dxf,     NULL,     1 },
+  { "geojson",    ".json",0, 1, 0,   NULL,     page_geojson, NULL,     1 },
   { "pgm",        ".pgm", 0, 1, 1,   NULL,     page_pgm,     NULL,     1 },
   { "gimppath",   ".svg", 0, 1, 0,   NULL,     page_gimp,    NULL,     1 },
   { "xfig",       ".fig", 1, 0, 0,   NULL,     page_xfig,    NULL,     0 },
@@ -206,6 +208,7 @@ static void usage(FILE *f) {
   fprintf(f, " -b pdf                     - PDF backend (portable document format)\n");
   fprintf(f, " -b pdfpage                 - fixed page-size PDF backend\n");
   fprintf(f, " -b dxf                     - DXF backend (drawing interchange format)\n");
+  fprintf(f, " -b geojson                 - GeoJSON backend\n");
   fprintf(f, " -b gimppath                - Gimppath backend (GNU Gimp)\n");
   fprintf(f, " -b xfig                    - XFig backend\n");
   fprintf(f, "Algorithm options:\n");
@@ -220,7 +223,7 @@ static void usage(FILE *f) {
   fprintf(f, " -P, --pagesize <format>    - page size (default is "DEFAULT_PAPERFORMAT")\n");
   fprintf(f, " -W, --width <dim>          - width of output image\n");
   fprintf(f, " -H, --height <dim>         - height of output image\n");
-  fprintf(f, " -r, --resolution <n>[x<n>] - resolution (in dpi)\n");
+  fprintf(f, " -r, --resolution <n>[x<n>] - resolution (in dpi) (dimension-based backends)\n");
   fprintf(f, " -x, --scale <n>[x<n>]      - scaling factor (pixel-based backends)\n");
   fprintf(f, " -S, --stretch <n>          - yresolution/xresolution\n");
   fprintf(f, " -A, --rotate <angle>       - rotate counterclockwise by angle\n");
@@ -231,7 +234,7 @@ static void usage(FILE *f) {
   fprintf(f, " -B, --bottommargin <dim>   - bottom margin\n");
   fprintf(f, " --tight                    - remove whitespace around the input image\n");
   fprintf(f, "Color options, supported by some backends:\n");
-  fprintf(f, " -C, --color #rrggbb        - set line color (default black)\n");
+  fprintf(f, " -C, --color #rrggbb        - set foreground color (default black)\n");
   fprintf(f, " --fillcolor #rrggbb        - set fill color (default transparent)\n");
   fprintf(f, " --opaque                   - make white shapes opaque\n");
   fprintf(f, "SVG options:\n");
@@ -482,13 +485,13 @@ static void dopts(int ac, char *av[]) {
       break;
     case 'v':
     case 'V':
-      fprintf(stdout, ""POTRACE" "VERSION". Copyright (C) 2001-2011 Peter Selinger.\n");
+      fprintf(stdout, ""POTRACE" "VERSION". Copyright (C) 2001-2013 Peter Selinger.\n");
       fprintf(stdout, "Library version: %s\n", potrace_version());
       show_defaults(stdout);
       exit(0);
       break;
     case 'l':
-      fprintf(stdout, ""POTRACE" "VERSION". Copyright (C) 2001-2011 Peter Selinger.\n\n");
+      fprintf(stdout, ""POTRACE" "VERSION". Copyright (C) 2001-2013 Peter Selinger.\n\n");
       license(stdout);
       exit(0);
       break;
