@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2011 Peter Selinger.
+/* Copyright (C) 2001-2013 Peter Selinger.
    This file is part of Potrace. It is free software and it is covered
    by the GNU General Public License. See the file COPYING for details. */
 
@@ -14,7 +14,7 @@ struct trans_s {
   double orig[2];  /* origin relative to bounding box */
   double x[2];     /* basis vector for the "x" direction */
   double y[2];     /* basis vector for the "y" direction */
-  double scalex, scaley;  /* redundant info for some backend's benefit */
+  double scalex, scaley;  /* redundant info for some backends' benefit */
 };
 typedef struct trans_s trans_t;
 
